if(NOT Boost_CONFIG_INCLUDED)
set(Boost_CONFIG_INCLUDED 1)

set(BOOST_VERSION 1.64.0)
set(Boost_VERSION 106400) # BOOST_VERSION value from boost/version.hpp

include(Common)

external_project_directories(boost ${BOOST_VERSION} BOOST_TMP_DIR BOOST_STAMP_DIR BOOST_DOWNLOAD_DIR BOOST_SOURCE_DIR BOOST_BINARY_DIR BOOST_INSTALL_DIR)
append_target_architecture_directory(${BOOST_INSTALL_DIR} BOOST_INSTALL_DIR)

if(NOT BOOST_ROOT)
	set(BOOST_ROOT ${BOOST_INSTALL_DIR})
endif()	

function(with_boost_libraries RESULT)
	foreach(LIBRARY ${ARGN})
		set(WITH_LIBRARIES ${WITH_LIBRARIES} --with-${LIBRARY})
	endforeach()
	set(${RESULT} ${WITH_LIBRARIES} PARENT_SCOPE)
endfunction()

function(with_boost_prefix_libraries RESULT)
	foreach(LIBRARY ${ARGN})
		set(BOOST_LIBRARIES ${BOOST_LIBRARIES} boost_${LIBRARY})
	endforeach()
	set(${RESULT} ${BOOST_LIBRARIES} PARENT_SCOPE)
endfunction()

function(boost_address_model RESULT)
    if(TARGET_32_BITS)
    	set(${RESULT} 32 PARENT_SCOPE)
    elseif(TARGET_64_BITS)
    	set(${RESULT} 64 PARENT_SCOPE)
    endif()
endfunction()

function(boost_bootstrap_command RESULT)
    set(${RESULT} ./bootstrap.sh  PARENT_SCOPE)
endfunction()

function(boost_build_command RESULT)
    set(${RESULT} b2 PARENT_SCOPE)
endfunction()

set(BOOST_EXTERNAL boost_external)

function(install_boost)
    if(NOT BOOST_INSTALL)
    	message(STATUS "Install Boost Libraries ${BOOST_VERSION}")
    
    	underscore_version(${BOOST_VERSION} BOOST_UNDERSCORE_VERSION)
    	set(BOOST_UNDERSCORE boost_${BOOST_UNDERSCORE_VERSION})
    	if(UNIX)
        	set(BOOST_URL http://downloads.sourceforge.net/project/boost/boost/${BOOST_VERSION}/${BOOST_UNDERSCORE}.tar.gz)
        	set(BOOST_MD5 319c6ffbbeccc366f14bb68767a6db79)
        else()
       	    set(BOOST_URL http://downloads.sourceforge.net/project/boost/boost/${BOOST_VERSION}/${BOOST_UNDERSCORE}.zip)
        	set(BOOST_MD5 36093e4018aecd5b0e31e80457ac5fc1)
    	endif()
    	
    	boost_bootstrap_command(BOOST_BOOTSTRAP_COMMAND)
    
    	ExternalProject_Add(${BOOST_EXTERNAL}
    		TMP_DIR ${BOOST_TMP_DIR}
    		STAMP_DIR ${BOOST_STAMP_DIR}
    		DOWNLOAD_DIR ${BOOST_DOWNLOAD_DIR}
    		SOURCE_DIR ${BOOST_SOURCE_DIR}
    		INSTALL_DIR ${BOOST_INSTALL_DIR}
    		
    		URL ${BOOST_URL}
    		URL_MD5 ${BOOST_MD5}
    		BUILD_IN_SOURCE 1
    		PATCH_COMMAND patch -p1 -i ${CMAKE_MODULE_PATH}/boost-${BOOST_VERSION}.patch
    		CONFIGURE_COMMAND ""
    		BUILD_COMMAND ${BOOST_BOOTSTRAP_COMMAND}
    	    INSTALL_COMMAND ${CMAKE_COMMAND} -E copy_directory "<SOURCE_DIR>/boost" "<INSTALL_DIR>/include/boost")
    	    
        set(BOOST_INSTALL 1 PARENT_SCOPE)	    
    endif()
endfunction()
	    
macro(find_boost)
    find_package(Boost ${BOOST_VERSION} EXACT)
    if(NOT Boost_FOUND)
    	install_boost()
      	include_directories(${BOOST_INSTALL_DIR}/include)
    else()
      	include_directories(${Boost_INCLUDE_DIRS})
    endif()
endmacro()

macro(require_boost_components)
    find_package(Boost ${BOOST_VERSION} REQUIRED EXACT COMPONENTS ${ARGN})
    include_directories(${Boost_INCLUDE_DIRS})
endmacro()

macro(find_boost_components)
    find_package(Boost ${BOOST_VERSION} EXACT COMPONENTS ${ARGN})
    if(NOT Boost_FOUND)
    	install_boost()
      	include_directories(${BOOST_INSTALL_DIR}/include)
    else()
      	include_directories(${Boost_INCLUDE_DIRS})
    endif()
endmacro()

remove_directory_command(REMOVE_DIRECTORY_COMMAND)

add_custom_target(clean_boost
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${BOOST_SOURCE_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${BOOST_INSTALL_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${BOOST_TMP_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${BOOST_STAMP_DIR})	

endif()
