set(PSTADE_VERSION 1.04.3)

include(Common)

external_project_directories(pstade ${PSTADE_VERSION} PSTADE_TMP_DIR PSTADE_STAMP_DIR PSTADE_DOWNLOAD_DIR PSTADE_SOURCE_DIR PSTADE_BINARY_DIR PSTADE_INSTALL_DIR)

if(NOT PSTADE_ROOT)
	set(PSTADE_ROOT ${PSTADE_INSTALL_DIR})
endif()

set(PSTADE_EXTERNAL pstade_external)

function(install_pstade)
	message(STATUS "Install PStade Library ${PSTADE_VERSION}")

	underscore_version(${PSTADE_VERSION} PSTADE_UNDERSCORE_VERSION)
	set(PSTADE_URL http://sourceforge.net/projects/p-stade/files/pstade/${PSTADE_VERSION}/pstade_${PSTADE_UNDERSCORE_VERSION}.zip)
	set(PSTADE_MD5 e44007e6bd5c6b42fe9945002d463ce2)
	
	ExternalProject_Add(${PSTADE_EXTERNAL}
		TMP_DIR ${PSTADE_TMP_DIR}
		STAMP_DIR ${PSTADE_STAMP_DIR}
		DOWNLOAD_DIR ${PSTADE_DOWNLOAD_DIR}
		SOURCE_DIR ${PSTADE_SOURCE_DIR}
		INSTALL_DIR ${PSTADE_INSTALL_DIR}
		
		URL ${PSTADE_URL}
		URL_MD5 ${PSTADE_MD5}
		BUILD_IN_SOURCE 1
		CONFIGURE_COMMAND ""
		BUILD_COMMAND ""
		INSTALL_COMMAND ${CMAKE_COMMAND} -E copy_directory "<SOURCE_DIR>/pstade" "<INSTALL_DIR>/include/pstade")
endfunction()

macro(require_pstade)
	find_package(PStade REQUIRED)
 	include_directories(${PStade_INCLUDE_DIR})
endmacro()

macro(find_pstade)
    find_package(PStade)
    if(NOT PStade_FOUND)
    	install_pstade()
	  	include_directories(${PSTADE_INSTALL_DIR}/include)
    else()	
 	  	include_directories(${PStade_INCLUDE_DIR})
    endif()
endmacro()

remove_directory_command(REMOVE_DIRECTORY_COMMAND)

add_custom_target(clean_pstade
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${PSTADE_SOURCE_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${PSTADE_BINARY_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${PSTADE_INSTALL_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${PSTADE_TMP_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${PSTADE_STAMP_DIR})	
