/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/algorithm/distance/feature_distance.hpp>
#include <geofis/algorithm/distance/attribute_distance.hpp>
#include <geofis/data/feature.hpp>
#include <geofis/util/algorithm/distance/euclidean_distance.hpp>
#include <geofis/util/algorithm/distance/minkowski_distance.hpp>
#include <CGAL/Cartesian.h>
#include <CGAL/Point_2.h>
#include <cppunit/extensions/HelperMacros.h>
#include <boost/variant.hpp>
#include <boost/assign/list_of.hpp>
#include <adobe/timer.hpp>

#include <geofis/util/algorithm/distance/variant_distance.hpp>
#include <util/type.hpp>

using namespace std;
using namespace CGAL;
using namespace util;
using namespace geofis;
using namespace boost;
using namespace boost::assign;

typedef Cartesian<double> kernel_type;
typedef Point_2<kernel_type> point_type;
typedef feature<char, point_type, vector<double> > feature_type;

typedef attribute_distance<minus<double> > minus_attribute_distance;
//typedef variant<attribute_distance<plus<double> >, attribute_distance<minus<double> > > variant_attribute_distance;
//typedef attribute_distance<variant<plus<double>, minus<double> > > variant_attribute_distance;
//typedef minus<double> minus_attribute_distance;

namespace boost {

// boost variant optimizations

template <> struct has_nothrow_copy<std::plus<double> > : false_type {};
template <> struct has_nothrow_constructor<std::plus<double> > : false_type {};
template <> struct has_nothrow_assign<std::plus<double> > : false_type {};
//template <> struct has_trivial_constructor<util::euclidean_distance> : true_type {};
//template <> struct has_trivial_copy<util::euclidean_distance> : true_type {};
//template <> struct has_trivial_assign<util::euclidean_distance> : true_type {};


template <> struct has_nothrow_copy<std::minus<double> > : false_type {};
template <> struct has_nothrow_constructor<std::minus<double> > : false_type {};
template <> struct has_nothrow_assign<std::minus<double> > : false_type {};
/*template <> struct has_trivial_constructor<util::minkowski_distance> : true_type {};
template <> struct has_trivial_copy<util::minkowski_distance> : true_type {};
template <> struct has_trivial_assign<util::minkowski_distance> : true_type {};*/

namespace detail { namespace variant {

template <> struct has_nothrow_move_constructor<std::plus<double> > : false_type {};
template <> struct has_nothrow_move_constructor<std::minus<double> > : false_type {};

}}

}  // namespace boost

typedef variant<plus<double>, minus<double> > variant_attribute_distance;

typedef feature_distance<euclidean_distance> feature_euclidean_distance_type;
typedef feature_distance<euclidean_distance, minus_attribute_distance> feature_euclidean_minus_distance_type;
typedef feature_distance<euclidean_distance, variant_attribute_distance> feature_euclidean_variant_distance_type;

struct other_distance {

	typedef double result_type;

	//other_distance() {}

	template <class Range> result_type operator()(const Range &range) const {
		return 0;
	}

	template <class T> result_type operator()(const T &lhs, const T &rhs) const {
		return 0;
	}

	double result;
};

//typedef variant<euclidean_distance, minkowski_distance> variant_distance;

typedef feature_distance<variant_distance> feature_variant_distance_type;
typedef feature_distance<variant_distance, minus_attribute_distance> feature_variant_minus_distance_type;
typedef feature_distance<variant_distance, variant_attribute_distance> feature_variant_variant_distance_type;

#define EPSILON 1e-6

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class feature_distance_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( feature_distance_tester );

	//CPPUNIT_TEST( test );
	CPPUNIT_TEST( test2 );
	CPPUNIT_TEST( test_performance );

	CPPUNIT_TEST_SUITE_END();

public:

	struct test_visitor : public boost::static_visitor<void> {

		test_visitor() : count(0) {}

		long int count;

	    template <class T> void operator()(const T&) {
	    	count ++;
	    }
	};


	void test2() {

		//BOOST_STATIC_ASSERT(( boost::has_trivial_copy<util::euclidean_distance>::value ));
		std::cout << "euclidean_distance\n";
		std::cout << util::Type<typename boost::has_nothrow_copy<euclidean_distance>::type>::name() << std::endl;
		//std::cout << util::Type<typename boost::has_trivial_copy<util::euclidean_distance>::type>::name() << std::endl;
		//std::cout << __has_trivial_copy(util::euclidean_distance) << std::endl;
		std::cout << util::Type<typename boost::has_nothrow_constructor<euclidean_distance>::type>::name() << std::endl;
		std::cout << util::Type<typename boost::detail::variant::has_nothrow_move_constructor<euclidean_distance>::type>::name() << std::endl;
		//std::cout << util::Type<typename boost::has_nothrow_copy<other_distance>::type>::name() << std::endl;
		std::cout << "minkowski_distance\n";
		std::cout << util::Type<typename boost::has_nothrow_copy<minkowski_distance>::type>::name() << std::endl;
		std::cout << util::Type<typename boost::has_nothrow_constructor<minkowski_distance>::type>::name() << std::endl;
		std::cout << util::Type<typename boost::detail::variant::has_nothrow_move_constructor<minkowski_distance>::type>::name() << std::endl;
		euclidean_distance ed;
		minkowski_distance md;
		std::cout << "-----------------\n";
		int a;
		int b;
		variant_distance vd(md);
		vd = ed;
		int c;
		int d;
		std::cout << "boost::addressof(a) " << boost::addressof(a) << std::endl;
		std::cout << "boost::addressof(b) " << boost::addressof(b) << std::endl;
		std::cout << "boost::addressof(vd) " << boost::addressof(vd) << std::endl;
		std::cout << "boost::addressof(c) " << boost::addressof(c) << std::endl;
		std::cout << "boost::addressof(d) " << boost::addressof(d) << std::endl;
		//vd = util::euclidean_distance();
		std::cout << "-----------------\n";
		test_visitor visitor;
		adobe::timer_t timer;
		long int count = 100000000;
		for(long int i = 0 ; i < count ; i++)
			boost::apply_visitor(visitor, vd);
		timer.report("visitation");
		std::cout << "-----------------\n";
		CPPUNIT_ASSERT_EQUAL(count, visitor.count);
	}

	void test() {

		try {

			feature_type feature1('a', point_type(), list_of(0.1)(0.4));
			feature_type feature2('b', point_type(), list_of(0.2)(0.9));

			double expected = sqrt(pow(0.1, 2) + pow(0.5, 2));

			CPPUNIT_ASSERT_DOUBLES_EQUAL( expected, feature_euclidean_distance_type()(feature1, feature2), EPSILON );

			CPPUNIT_ASSERT_DOUBLES_EQUAL( expected, feature_variant_distance_type()(feature1, feature2), EPSILON );

			CPPUNIT_ASSERT_DOUBLES_EQUAL( expected, feature_euclidean_minus_distance_type(2)(feature1, feature2), EPSILON );

			CPPUNIT_ASSERT_DOUBLES_EQUAL( expected, feature_variant_minus_distance_type(2)(feature1, feature2), EPSILON );

			CPPUNIT_ASSERT_DOUBLES_EQUAL( expected, feature_euclidean_variant_distance_type(2, variant_attribute_distance(minus<double>()))(feature1, feature2), EPSILON );

			CPPUNIT_ASSERT_DOUBLES_EQUAL( expected, feature_variant_variant_distance_type(2, variant_attribute_distance(minus<double>()))(feature1, feature2), EPSILON );

			CPPUNIT_ASSERT_DOUBLES_EQUAL( expected, feature_euclidean_minus_distance_type(list_of(minus<double>())(minus<double>()))(feature1, feature2), EPSILON );

			CPPUNIT_ASSERT_DOUBLES_EQUAL( sqrt(pow(0.1, 2) + pow(1.3, 2)), feature_euclidean_variant_distance_type(list_of(variant_attribute_distance(minus<double>()))(variant_attribute_distance(plus<double>())))(feature1, feature2), EPSILON );

			CPPUNIT_ASSERT_DOUBLES_EQUAL( expected, feature_variant_variant_distance_type(list_of(variant_attribute_distance(minus<double>()))(variant_attribute_distance(minus<double>())))(feature1, feature2), EPSILON );

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}

	template <class FeatureDistance> void test_performance(const FeatureDistance &feature_distance, const char *decoration) {

		feature_type feature1('a', point_type(), list_of(0.1)(0.2)(0.3)(0.4));
		feature_type feature2('b', point_type(), list_of(0.2)(0.4)(0.6)(0.8));

		//double expected = sqrt(pow(0.1, 2) + pow(0.2, 2) + pow(0.3, 2) + pow(0.4, 2));
		long count = 1000000;
		//double distance = 0;

		adobe::timer_t timer;
		for(long i = 0 ; i < count ; i++)
			/*distance +=*/ feature_distance(feature1, feature2);
		timer.report(decoration);
		//CPPUNIT_ASSERT_DOUBLES_EQUAL( expected * count, distance, EPSILON );
	}

	void test_performance() {

		try {

			/*test_performance(feature_euclidean_distance_type(), "feature_distance<euclidean_distance>");
			test_performance(feature_variant_distance_type(), "feature_distance<variant_distance>");
			test_performance(feature_euclidean_minus_distance_type(4), "feature_distance<euclidean_distance, minus<double> >");
			test_performance(feature_variant_minus_distance_type(4), "feature_distance<variant_distance, minus<double> >");
			test_performance(feature_euclidean_variant_distance_type(4, variant_attribute_distance(minus<double>())), "feature_distance<euclidean_distance, variant_attribute_distance>");
			test_performance(feature_variant_variant_distance_type(4, variant_attribute_distance(minus<double>())), "feature_distance<variant_distance, variant_attribute_distance>");
			test_performance(feature_euclidean_minus_distance_type(list_of(minus<double>())(minus<double>())(minus<double>())(minus<double>())), "feature_distance<euclidean_distance, minus<double> >");
			test_performance(feature_euclidean_variant_distance_type(list_of(variant_attribute_distance(minus<double>()))(variant_attribute_distance(minus<double>()))(variant_attribute_distance(minus<double>()))(variant_attribute_distance(minus<double>()))), "feature_distance<euclidean_distance, variant_attribute_distance>");
	*/		test_performance(feature_variant_variant_distance_type(list_of(variant_attribute_distance(minus<double>()))(variant_attribute_distance(minus<double>()))(variant_attribute_distance(minus<double>()))(variant_attribute_distance(minus<double>()))), "feature_distance<variant_distance, variant_attribute_distance>");

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( feature_distance_tester );
