/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/algorithm/zoning/zone_distance.hpp>
#include <geofis/algorithm/zoning/zone.hpp>
#include <geofis/algorithm/zoning/variant_zone_distance.hpp>
#include <geofis/data/feature.hpp>
#include <geofis/util/algorithm/distance/euclidean_distance.hpp>
#include <geofis/algorithm/distance/feature_distance.hpp>
#include <boost/assign/list_of.hpp>
#include <CGAL/Cartesian.h>
#include <CGAL/Point_2.h>
#include <CGAL/Polygon_2.h>
#include <cppunit/extensions/HelperMacros.h>

using namespace std;
using namespace CGAL;
using namespace util;
using namespace geofis;
using namespace boost;
using namespace boost::assign;

typedef Cartesian<double> kernel_type;
typedef Point_2<kernel_type> point_type;
typedef Polygon_2<kernel_type> polygon_type;
typedef feature<char, point_type, vector<double> > feature_type;
typedef zone<polygon_type, feature_type> zone_type;

typedef feature_distance<euclidean_distance> feature_distance_type;

#define EPSILON 1e-6

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class zone_distance_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( zone_distance_tester );

	CPPUNIT_TEST( test );

	CPPUNIT_TEST_SUITE_END();

public:

	void test() {

		try {

			feature_type feature1('a', point_type(), list_of(0.1)(0.2));
			feature_type feature2('b', point_type(), list_of(0.2)(0.3));
			feature_type feature3('c', point_type(), list_of(0.3)(0.4));
			feature_type feature4('d', point_type(), list_of(0.4)(0.5));
			feature_type feature5('e', point_type(), list_of(0.5)(0.6));

			zone_type zone1(list_of(cref(feature1))(cref(feature2)));
			zone_type zone2(list_of(cref(feature3))(cref(feature4))(cref(feature5)));

			double distance = zone_distance<util::min<double>, feature_distance_type>()(zone1, zone2);
			double min_expected = sqrt(pow(0.1, 2) + pow(0.1, 2));
			CPPUNIT_ASSERT_DOUBLES_EQUAL( min_expected, distance, EPSILON );

			distance = zone_distance<util::max<double>, feature_distance_type>()(zone1, zone2);
			double max_expected = sqrt(pow(0.4, 2) + pow(0.4, 2));
			CPPUNIT_ASSERT_DOUBLES_EQUAL( max_expected, distance, EPSILON );

			distance = zone_distance<util::mean<double>, feature_distance_type>()(zone1, zone2);
			double mean_expected = (sqrt(pow(0.1, 2) + pow(0.1, 2)) +  (2 * sqrt(pow(0.2, 2) + pow(0.2, 2))) +  (2 * sqrt(pow(0.3, 2) + pow(0.3, 2))) + sqrt(pow(0.4, 2) + pow(0.4, 2))) / 6;
			CPPUNIT_ASSERT_DOUBLES_EQUAL( mean_expected, distance, EPSILON );

			distance = zone_distance<variant_zone_distance, feature_distance_type>(variant_zone_distance(util::min<double>()))(zone1, zone2);
			CPPUNIT_ASSERT_DOUBLES_EQUAL( min_expected, distance, EPSILON );

			distance = zone_distance<variant_zone_distance, feature_distance_type>(variant_zone_distance(util::max<double>()))(zone1, zone2);
			CPPUNIT_ASSERT_DOUBLES_EQUAL( max_expected, distance, EPSILON );

			distance = zone_distance<variant_zone_distance, feature_distance_type>(variant_zone_distance(util::mean<double>()))(zone1, zone2);
			CPPUNIT_ASSERT_DOUBLES_EQUAL( mean_expected, distance, EPSILON );

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( zone_distance_tester );
