/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/algorithm/zoning/fusion/map/fusion_map.hpp>
#include <boost/ref.hpp>
#include <boost/utility.hpp>
#include <boost/assign/list_of.hpp>
#include <boost/range/algorithm/for_each.hpp>
#include <util/address_equal.hpp>
//#include <boost/range/sub_range.hpp>
//#include <boost/type_traits/remove_const.hpp>
//#include <pstade/oven/taken.hpp>
//#include <geofis/algorithm/zoning/zone_address_equal.hpp>
#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/specializations.hpp>
#include <vector>
#include <list>

using namespace std;
using namespace geofis;
using namespace boost;
using namespace boost::assign;

struct zone {

	friend bool operator==(const zone &lhs, const zone &rhs) {
		return util::address_equal(lhs, rhs);
	}
};

struct zone_fusion {

	typedef zone zone_type;
	typedef typename boost::reference_wrapper<const zone> zone_reference;

	zone_fusion(const zone &zone1, const zone &zone2) : zone1(zone1), zone2(zone2) {}

	zone &get_fusion() { return fusion; }
	const zone &get_fusion() const { return fusion; }

	bool contain_zone(const zone &zone) const {
		return util::address_equal(zone, unwrap_ref(zone1)) || util::address_equal(zone, unwrap_ref(zone2));
	}

	zone_reference zone1;
	zone_reference zone2;
	zone fusion;
};

template <class FusionRange> const zone &fusion(const FusionRange &fusion_range, int index) {
	return next(begin(fusion_range), index)->get_fusion();
}

typedef vector<zone> zone_range_type;
typedef list<zone_fusion> zone_fusion_range_type;
typedef typename fusion_map_traits<zone_range_type, zone_fusion_range_type>::type fusion_map_type;
typedef vector<fusion_map_type> fusion_maps_type;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class fusion_map_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( fusion_map_tester );

	CPPUNIT_TEST( test );

	CPPUNIT_TEST_SUITE_END();

public:

	template <class FusionStep> void test_step1(const FusionStep &step1, const vector<zone> &zones, const list<zone_fusion> &fusions) {
		CPPUNIT_ASSERT_EQUAL( 9, distance(step1.zone_range()) );
		CPPUNIT_ASSERT_RANGES_EQUAL( list_of(cref(zones[2]))(cref(zones[3]))(cref(zones[4]))(cref(zones[5]))(cref(zones[6]))(cref(zones[7]))(cref(zones[8]))(cref(zones[9]))(cref(::fusion(fusions, 0))), step1.zone_range() );
	}

	template <class FusionStep> void test_step2(const FusionStep &step2, const vector<zone> &zones, const list<zone_fusion> &fusions) {
		CPPUNIT_ASSERT_EQUAL( 8, distance(step2.zone_range()) );
		CPPUNIT_ASSERT_RANGES_EQUAL( list_of(cref(zones[2]))(cref(zones[5]))(cref(zones[6]))(cref(zones[7]))(cref(zones[8]))(cref(zones[9]))(cref(::fusion(fusions, 0)))(cref(::fusion(fusions, 1))), step2.zone_range() );
	}

	template <class FusionStep> void test_step3(const FusionStep &step3, const vector<zone> &zones, const list<zone_fusion> &fusions) {
		CPPUNIT_ASSERT_EQUAL( 7, distance(step3.zone_range()) );
		CPPUNIT_ASSERT_RANGES_EQUAL( list_of(cref(zones[2]))(cref(zones[6]))(cref(zones[7]))(cref(zones[8]))(cref(zones[9]))(cref(::fusion(fusions, 0)))(cref(::fusion(fusions, 2))), step3.zone_range() );
	}

	template <class FusionStep> void test_step4(const FusionStep &step4, const vector<zone> &zones, const list<zone_fusion> &fusions) {
		CPPUNIT_ASSERT_EQUAL( 6, distance(step4.zone_range()) );
		CPPUNIT_ASSERT_RANGES_EQUAL( list_of(cref(zones[2]))(cref(zones[6]))(cref(zones[7]))(cref(zones[8]))(cref(zones[9]))(cref(::fusion(fusions, 3))), step4.zone_range() );
	}

	template <class FusionStep> void test_step5(const FusionStep &step5, const vector<zone> &zones, const list<zone_fusion> &fusions) {
		CPPUNIT_ASSERT_EQUAL( 5, distance(step5.zone_range()) );
		CPPUNIT_ASSERT_RANGES_EQUAL( list_of(cref(zones[6]))(cref(zones[7]))(cref(zones[8]))(cref(zones[9]))(cref(::fusion(fusions, 4))), step5.zone_range() );
	}

	struct no_const_zone_tester {

		void operator()(zone &zone) const {}
	};

	template <class FusionStep> void test_no_const_fusion_map(FusionStep &fusion_map) {
		test_no_const_zones(fusion_map.zone_range());
	}

	template <class FusionStep> void test_const_fusion_map(const FusionStep &fusion_map) {
		test_no_const_zones(fusion_map.zone_range());
	}

	template <class ZoneRange> void test_no_const_zones(ZoneRange zones) {
		boost::for_each(zones, no_const_zone_tester());
	}

	void test() {

		try {

			vector<zone> zones = list_of(zone())(zone())(zone())(zone())(zone())(zone())(zone())(zone())(zone())(zone());
			list<zone_fusion> fusions;
			fusion_maps_type fusion_maps;

			fusions.push_back(zone_fusion(zones[0], zones[1]));
			fusion_maps.push_back(make_fusion_map(zones, fusions));
			test_step1(fusion_maps[0], zones, fusions);

			fusions.push_back(zone_fusion(zones[3], zones[4]));
			fusion_maps.push_back(make_fusion_map(zones, fusions));
			test_step2(fusion_maps[1], zones, fusions);
			test_step1(fusion_maps[0], zones, fusions);

			fusions.push_back(zone_fusion(::fusion(fusions, 1), zones[5]));
			fusion_maps.push_back(make_fusion_map(zones, fusions));
			test_step3(fusion_maps[2], zones, fusions);
			test_step2(fusion_maps[1], zones, fusions);
			test_step1(fusion_maps[0], zones, fusions);

			fusions.push_back(zone_fusion(::fusion(fusions, 0), ::fusion(fusions, 2)));
			fusion_maps.push_back(make_fusion_map(zones, fusions));
			test_step4(fusion_maps[3], zones, fusions);
			test_step3(fusion_maps[2], zones, fusions);
			test_step2(fusion_maps[1], zones, fusions);
			test_step1(fusion_maps[0], zones, fusions);

			fusions.push_back(zone_fusion(zones[2], ::fusion(fusions, 3)));
			fusion_maps.push_back(make_fusion_map(zones, fusions));
			test_step5(fusion_maps[4], zones, fusions);
			test_step4(fusion_maps[3], zones, fusions);
			test_step3(fusion_maps[2], zones, fusions);
			test_step2(fusion_maps[1], zones, fusions);
			test_step1(fusion_maps[0], zones, fusions);

			test_step5(make_fusion_map(zones, pstade::oven::make_taken(fusions, 5)), zones, fusions);
			test_step4(make_fusion_map(zones, pstade::oven::make_taken(fusions, 4)), zones, fusions);
			test_step3(make_fusion_map(zones, pstade::oven::make_taken(fusions, 3)), zones, fusions);
			test_step2(make_fusion_map(zones, pstade::oven::make_taken(fusions, 2)), zones, fusions);
			test_step1(make_fusion_map(zones, pstade::oven::make_taken(fusions, 1)), zones, fusions);

			fusion_map_type no_const_fusion_map(make_fusion_map(zones, fusions));
			test_no_const_fusion_map(no_const_fusion_map);

			// uncomment the following lines causes a compile error
			//test_const_fusion_map(make_fusion_map(vector<zone>()));
			//test_const_fusion_map(make_fusion_map(zones, pstade::oven::make_taken2(fusions, fusions.size())));

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( fusion_map_tester );
