/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/algorithm/zoning/fusion/zone_fusion.hpp>
#include <geofis/algorithm/zoning/pair/zone_pair.hpp>
#include <geofis/algorithm/zoning/pair/zone_pair_distance.hpp>
#include <geofis/algorithm/zoning/pair/zone_pair_updater.hpp>
#include <geofis/algorithm/zoning/zone_joinable_length_filter.hpp>
#include <geofis/algorithm/zoning/triangulation/edge_to_zone_pair.hpp>
#include <geofis/data/feature.hpp>
#include <geofis/data/geometry_iterator.hpp>
#include <geofis/algorithm/zoning/zone.hpp>
#include <geofis/algorithm/zoning/triangulation/voronoi/voronoi_traits.hpp>
#include <geofis/algorithm/zoning/triangulation/voronoi/face_to_geometry.hpp>
#include <geofis/algorithm/zoning/triangulation/voronoi/face_to_polygon.hpp>
#include <geofis/algorithm/zoning/triangulation/edge_to_zone_adaptor.hpp>
#include <geofis/algorithm/zoning/find_zone_pair.hpp>
#include <geofis/algorithm/zoning/find_zone_pair_id.hpp>
#include <geofis/algorithm/zoning/find_zone_id.hpp>
#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/specializations.hpp>
#include <CGAL/Cartesian.h>
#include <CGAL/Polygon_with_holes_2.h>
#include <boost/utility.hpp>
#include <boost/assign/list_of.hpp>
#include <boost/range/adaptor/transformed.hpp>
#include <boost/iterator/filter_iterator.hpp>
#include <boost/range/algorithm/count.hpp>
#include <boost/range/algorithm/find_if.hpp>
#include <boost/range/algorithm/for_each.hpp>
#include <boost/range/algorithm_ext.hpp>
#include <pstade/oven/exists.hpp>
#include <geofis/geometry/polygon_with_holes.hpp>
#include <geofis/data/feature_io.hpp>
#include <geofis/data/feature_to_id.hpp>
#include <geofis/algorithm/distance/feature_distance.hpp>
#include <geofis/algorithm/zoning/zone_distance.hpp>
#include <geofis/util/algorithm/distance/euclidean_distance.hpp>
#include <util/range/algorithm/max_value.hpp>
#include <list>

using namespace std;
using namespace util;
using namespace geofis;
using namespace CGAL;
using namespace boost;
using namespace boost::assign;
using namespace boost::adaptors;
using namespace pstade::oven;

typedef Cartesian<double> kernel_type;
typedef Point_2<kernel_type> point_type;
typedef Polygon_2<kernel_type> polygon_type;
typedef Polygon_with_holes_2<kernel_type> polygon_with_hole_type;

typedef feature<char, point_type, vector<double> > feature_type;
typedef vector<feature_type> vector_feature_type;

typedef geofis::zone<polygon_with_hole_type, feature_type> zone_type;
typedef vector<zone_type> vector_zone_type;
typedef zone_fusion<zone_type> zone_fusion_type;

//typedef zone_pair<zone_type> zone_pair_type;

typedef typename voronoi_traits<kernel_type, zone_type *>::delaunay_triangulation_type delaunay_triangulation_type;
typedef typename voronoi_traits<kernel_type, zone_type *>::voronoi_diagram_type voronoi_diagram_type;

typedef edge_to_zone_adaptor<zone_joinable_length_filter> zone_joinable_length_filter_type;

typedef feature_distance<euclidean_distance> feature_distance_type;
typedef util::range::max_value<double> zone_distance_type;
typedef zone_pair_distance<zone_distance_type> zone_pair_distance_type;
typedef zone_pair<zone_type, zone_pair_distance_type> zone_pair_type;
typedef list<zone_pair_type> zone_pair_container_type;
typedef zone_pair_container_type::iterator zone_pair_iterator;
typedef edge_to_zone_pair<zone_type, zone_pair_distance_type, feature_distance_type> edge_to_zone_pair_type;
typedef zone_pair_updater<feature_distance_type> zone_pair_updater_type;

#define EPSILON 1e-6

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class zone_fusion_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( zone_fusion_tester );

	CPPUNIT_TEST( test );

	CPPUNIT_TEST_SUITE_END();

public:

	template <class Range> struct find_in_range {

		find_in_range(const Range &range) : range(range) {}

		template <class T> void operator()(T value) {
			found = count(range, value) == 1;
		}

		const Range &range;
		bool found;
	};

	template <class ExpectedRange, class Range> void check_ids(const ExpectedRange &expected_range, const Range &range) {
		CPPUNIT_ASSERT( for_each(expected_range, find_in_range<Range>(range)).found );
	}

	template <class ZonePairFinder> void check_zone_pair(const zone_pair_container_type &zone_pairs, const ZonePairFinder &zone_pair_finder, double expected_distance) {
		CPPUNIT_ASSERT( exists(zone_pairs, zone_pair_finder) );
		CPPUNIT_ASSERT_DOUBLES_EQUAL( expected_distance, find_if(zone_pairs, zone_pair_finder)->get_distance(), EPSILON );
		//CPPUNIT_ASSERT_DOUBLES_EQUAL( expected_distance, zone_distance_type()(*find_if(zone_pairs, zone_pair_finder)), EPSILON );
	}

	void test() {

		try {

			feature_type feature1('a', point_type(0.5, 0.5), list_of(0.1)(0.2));
			feature_type feature2('b', point_type(1.5, 0.5), list_of(0.2)(0.3));
			feature_type feature3('c', point_type(2.5, 0.5), list_of(0.3)(0.4));
			feature_type feature4('d', point_type(0.5, 1.5), list_of(0.4)(0.5));
			feature_type feature5('e', point_type(1.5, 1.5), list_of(0.5)(0.6));
			feature_type feature6('f', point_type(2.5, 1.5), list_of(0.6)(0.7));
			feature_type feature7('g', point_type(0.5, 2.5), list_of(0.7)(0.8));
			feature_type feature8('h', point_type(1.5, 2.5), list_of(0.8)(0.9));
			feature_type feature9('i', point_type(2.5, 2.5), list_of(0.9)(1.0));
			vector_feature_type features = list_of(feature1)(feature2)(feature3)(feature4)(feature5)(feature6)(feature7)(feature8)(feature9);

			vector_zone_type zones(make_transform_iterator(features.begin(), make_zone<polygon_with_hole_type, feature_type>()), make_transform_iterator(features.end(), make_zone<polygon_with_hole_type, feature_type>()));

			delaunay_triangulation_type delaunay;
			delaunay.insert(make_zip_iterator(make_tuple(make_geometry_iterator(features.begin()), make_transform_iterator(zones.begin(), &addressof<zone_type>))), make_zip_iterator(make_tuple(make_geometry_iterator(features.end()), make_transform_iterator(zones.end(), &addressof<zone_type>))));
			voronoi_diagram_type voronoi(delaunay, true);
			CPPUNIT_ASSERT_EQUAL( (size_t)9, zones.size() );
			CPPUNIT_ASSERT_EQUAL( zones.size(), voronoi.number_of_faces() );

			polygon_type boundary_polygon = make_polygon<kernel_type>(list_of(point_type(0, 0))(point_type(3, 0))(point_type(3, 3))(point_type(0, 3)));

			for_each(voronoi.faces_begin(), voronoi.faces_end(), make_face_to_geometry(make_face_to_polygon(boundary_polygon)));

			zone_joinable_length_filter_type zone_joinable_length_filter(0.5);
			zone_distance_type _zone_distance;
			feature_distance_type _feature_distance;
			edge_to_zone_pair_type _edge_to_zone_pair(_zone_distance, _feature_distance);
			zone_pair_updater_type _zone_pair_updater(_feature_distance);
			//zone_pair_container_type zone_pairs(make_filter_iterator(zone_joinable_length_filter, make_transform_iterator(voronoi.dual().finite_edges_begin(), edge_to_zone_pair_type()), make_transform_iterator(voronoi.dual().finite_edges_end(), edge_to_zone_pair_type())), make_filter_iterator(zone_joinable_length_filter, make_transform_iterator(voronoi.dual().finite_edges_end(), edge_to_zone_pair_type()), make_transform_iterator(voronoi.dual().finite_edges_end(), edge_to_zone_pair_type())));
			//zone_pair_container_type zone_pairs;
			zone_pair_container_type zone_pairs(make_transform_iterator(make_filter_iterator(zone_joinable_length_filter, voronoi.dual().finite_edges_begin(),voronoi.dual().finite_edges_end()), _edge_to_zone_pair), make_transform_iterator(make_filter_iterator(zone_joinable_length_filter, voronoi.dual().finite_edges_end(), voronoi.dual().finite_edges_end()), _edge_to_zone_pair));

			//copy(zone_pairs, ostream_iterator<zone_pair_type>(cout, "\n"));

			CPPUNIT_ASSERT_EQUAL( (size_t)12, zone_pairs.size() );
			check_zone_pair(zone_pairs, zone_pair_id_finder('a', 'b'), sqrt(0.02));
			check_zone_pair(zone_pairs, zone_pair_id_finder('a', 'd'), sqrt(0.18));
			check_zone_pair(zone_pairs, zone_pair_id_finder('b', 'c'), sqrt(0.02));
			check_zone_pair(zone_pairs, zone_pair_id_finder('b', 'e'), sqrt(0.18));
			check_zone_pair(zone_pairs, zone_pair_id_finder('c', 'f'), sqrt(0.18));
			check_zone_pair(zone_pairs, zone_pair_id_finder('d', 'e'), sqrt(0.02));
			check_zone_pair(zone_pairs, zone_pair_id_finder('d', 'g'), sqrt(0.18));
			check_zone_pair(zone_pairs, zone_pair_id_finder('e', 'f'), sqrt(0.02));
			check_zone_pair(zone_pairs, zone_pair_id_finder('e', 'h'), sqrt(0.18));
			check_zone_pair(zone_pairs, zone_pair_id_finder('f', 'i'), sqrt(0.18));
			check_zone_pair(zone_pairs, zone_pair_id_finder('g', 'h'), sqrt(0.02));
			check_zone_pair(zone_pairs, zone_pair_id_finder('h', 'i'), sqrt(0.02));

			//copy(zone_pairs, ostream_iterator<zone_pair_type>(cout, "\n"));

			zone_pair_iterator zone_pair_to_fusion = find_if(zone_pairs, zone_pair_id_finder('a', 'b'));
			zone_fusion_type zone_k(*zone_pair_to_fusion);
			check_ids(string("ab"), transform(zone_k.get_fusion().feature_range(), feature_to_id<char>()));
			CPPUNIT_ASSERT_EQUAL( make_polygon_with_holes<kernel_type>(list_of(point_type(0, 0))(point_type(1, 0))(point_type(2, 0))(point_type(2, 1))(point_type(1, 1))(point_type(0, 1))), zone_k.get_fusion().get_geometry() );
			zone_pairs.erase(zone_pair_to_fusion);
			_zone_pair_updater.update_zone_pairs(zone_pairs, zone_k);

			CPPUNIT_ASSERT_EQUAL( (size_t)11, zone_pairs.size() );
			check_zone_pair(zone_pairs, zone_pair_finder(zone_k.get_fusion(), *find_if(zones, zone_id_finder('d'))), sqrt(0.18));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_k.get_fusion(), *find_if(zones, zone_id_finder('c'))), sqrt(0.08));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_k.get_fusion(), *find_if(zones, zone_id_finder('e'))), sqrt(0.32));

			//copy(zone_pairs, ostream_iterator<zone_pair_type>(cout, "\n"));

			zone_pair_to_fusion = find_if(zone_pairs, zone_pair_id_finder('d', 'e'));
			zone_fusion_type zone_l(*zone_pair_to_fusion);
			check_ids(string("ed"), transform(zone_l.get_fusion().feature_range(), feature_to_id<char>()));
			CPPUNIT_ASSERT_EQUAL( make_polygon_with_holes<kernel_type>(list_of(point_type(0, 1))(point_type(1, 1))(point_type(2, 1))(point_type(2, 2))(point_type(1, 2))(point_type(0, 2))), zone_l.get_fusion().get_geometry() );
			zone_pairs.erase(zone_pair_to_fusion);
			_zone_pair_updater.update_zone_pairs(zone_pairs, zone_l);

			CPPUNIT_ASSERT_EQUAL( (size_t)9, zone_pairs.size() );
			check_zone_pair(zone_pairs, zone_pair_finder(zone_l.get_fusion(), zone_k.get_fusion()), sqrt(0.32));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_l.get_fusion(), *find_if(zones, zone_id_finder('g'))), sqrt(0.18));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_l.get_fusion(), *find_if(zones, zone_id_finder('f'))), sqrt(0.08));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_l.get_fusion(), *find_if(zones, zone_id_finder('h'))), sqrt(0.32));

			//copy(zone_pairs, ostream_iterator<zone_pair_type>(cout, "\n"));

			zone_pair_to_fusion = find_if(zone_pairs, zone_pair_finder(zone_l.get_fusion(), zone_k.get_fusion()));
			zone_fusion_type zone_m(*zone_pair_to_fusion);
			check_ids(string("abed"), transform(zone_m.get_fusion().feature_range(), feature_to_id<char>()));
			CPPUNIT_ASSERT_EQUAL( make_polygon_with_holes<kernel_type>(list_of(point_type(0, 0))(point_type(1, 0))(point_type(2, 0))(point_type(2, 1))(point_type(2, 2))(point_type(1, 2))(point_type(0, 2))(point_type(0, 1))), zone_m.get_fusion().get_geometry() );
			zone_pairs.erase(zone_pair_to_fusion);
			_zone_pair_updater.update_zone_pairs(zone_pairs, zone_m);

			CPPUNIT_ASSERT_EQUAL( (size_t)8, zone_pairs.size() );
			check_zone_pair(zone_pairs, zone_pair_finder(zone_m.get_fusion(), *find_if(zones, zone_id_finder('g'))), sqrt(0.72));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_m.get_fusion(), *find_if(zones, zone_id_finder('h'))), sqrt(0.98));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_m.get_fusion(), *find_if(zones, zone_id_finder('f'))), sqrt(0.50));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_m.get_fusion(), *find_if(zones, zone_id_finder('c'))), sqrt(0.08));

			//copy(zone_pairs, ostream_iterator<zone_pair_type>(cout, "\n"));

			zone_pair_to_fusion = find_if(zone_pairs, zone_pair_id_finder('c', 'f'));
			zone_fusion_type zone_n(*zone_pair_to_fusion);
			check_ids(string("cf"), transform(zone_n.get_fusion().feature_range(), feature_to_id<char>()));
			CPPUNIT_ASSERT_EQUAL( make_polygon_with_holes<kernel_type>(list_of(point_type(3, 0))(point_type(3, 1))(point_type(3, 2))(point_type(2, 2))(point_type(2, 1))(point_type(2, 0))), zone_n.get_fusion().get_geometry() );
			zone_pairs.erase(zone_pair_to_fusion);
			_zone_pair_updater.update_zone_pairs(zone_pairs, zone_n);

			CPPUNIT_ASSERT_EQUAL( (size_t)6, zone_pairs.size() );
			check_zone_pair(zone_pairs, zone_pair_finder(zone_n.get_fusion(), zone_m.get_fusion()), sqrt(0.50));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_n.get_fusion(), *find_if(zones, zone_id_finder('i'))), sqrt(0.72));

			//copy(zone_pairs, ostream_iterator<zone_pair_type>(cout, "\n"));

			zone_pair_to_fusion = find_if(zone_pairs, zone_pair_finder(zone_n.get_fusion(), *find_if(zones, zone_id_finder('i'))));
			zone_fusion_type zone_o(*zone_pair_to_fusion);
			check_ids(string("icf"), transform(zone_o.get_fusion().feature_range(), feature_to_id<char>()));
			CPPUNIT_ASSERT_EQUAL( make_polygon_with_holes<kernel_type>(list_of(point_type(3, 0))(point_type(3, 1))(point_type(3, 2))(point_type(3, 3))(point_type(2, 3))(point_type(2, 2))(point_type(2, 1))(point_type(2, 0))), zone_o.get_fusion().get_geometry() );
			zone_pairs.erase(zone_pair_to_fusion);
			_zone_pair_updater.update_zone_pairs(zone_pairs, zone_o);

			CPPUNIT_ASSERT_EQUAL( (size_t)5, zone_pairs.size() );
			check_zone_pair(zone_pairs, zone_pair_finder(zone_o.get_fusion(), zone_m.get_fusion()), sqrt(1.28));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_o.get_fusion(), *find_if(zones, zone_id_finder('h'))), sqrt(0.50));

			//copy(zone_pairs, ostream_iterator<zone_pair_type>(cout, "\n"));

			zone_pair_to_fusion = find_if(zone_pairs, zone_pair_id_finder('g', 'h'));
			zone_fusion_type zone_p(*zone_pair_to_fusion);
			check_ids(string("gh"), transform(zone_p.get_fusion().feature_range(), feature_to_id<char>()));
			CPPUNIT_ASSERT_EQUAL( make_polygon_with_holes<kernel_type>(list_of(point_type(0, 2))(point_type(1, 2))(point_type(2, 2))(point_type(2, 3))(point_type(1, 3))(point_type(0, 3))), zone_p.get_fusion().get_geometry() );
			zone_pairs.erase(zone_pair_to_fusion);
			_zone_pair_updater.update_zone_pairs(zone_pairs, zone_p);

			CPPUNIT_ASSERT_EQUAL( (size_t)3, zone_pairs.size() );
			check_zone_pair(zone_pairs, zone_pair_finder(zone_p.get_fusion(), zone_m.get_fusion()), sqrt(0.98));
			check_zone_pair(zone_pairs, zone_pair_finder(zone_p.get_fusion(), zone_o.get_fusion()), sqrt(0.50));

			//copy(zone_pairs, ostream_iterator<zone_pair_type>(cout, "\n"));

			zone_pair_to_fusion = find_if(zone_pairs, zone_pair_finder(zone_m.get_fusion(), zone_p.get_fusion()));
			zone_fusion_type zone_q(*zone_pair_to_fusion);
			check_ids(string("abedgh"), transform(zone_q.get_fusion().feature_range(), feature_to_id<char>()));
			CPPUNIT_ASSERT_EQUAL( make_polygon_with_holes<kernel_type>(list_of(point_type(0, 0))(point_type(1, 0))(point_type(2, 0))(point_type(2, 1))(point_type(2, 2))(point_type(2, 3))(point_type(1, 3))(point_type(0, 3))(point_type(0, 2))(point_type(0, 1))), zone_q.get_fusion().get_geometry() );
			zone_pairs.erase(zone_pair_to_fusion);
			_zone_pair_updater.update_zone_pairs(zone_pairs, zone_q);

			CPPUNIT_ASSERT_EQUAL( (size_t)1, zone_pairs.size() );
			check_zone_pair(zone_pairs, zone_pair_finder(zone_q.get_fusion(), zone_o.get_fusion()), sqrt(1.28));

			//copy(zone_pairs, ostream_iterator<zone_pair_type>(cout, "\n"));
			zone_pair_to_fusion = find_if(zone_pairs, zone_pair_finder(zone_q.get_fusion(), zone_o.get_fusion()));
			zone_fusion_type zone_r(*zone_pair_to_fusion);
			check_ids(string("abedghicf"), transform(zone_r.get_fusion().feature_range(), feature_to_id<char>()));
			CPPUNIT_ASSERT_EQUAL( make_polygon_with_holes<kernel_type>(list_of(point_type(0, 0))(point_type(1, 0))(point_type(2, 0))(point_type(3, 0))(point_type(3, 1))(point_type(3, 2))(point_type(3, 3))(point_type(2, 3))(point_type(1, 3))(point_type(0, 3))(point_type(0, 2))(point_type(0, 1))), zone_r.get_fusion().get_geometry() );
			zone_pairs.erase(zone_pair_to_fusion);
			CPPUNIT_ASSERT( zone_pairs.empty() );

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( zone_fusion_tester );

