/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/algorithm/zoning/zone.hpp>
#include <geofis/data/feature.hpp>
#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/specializations.hpp>
#include <CGAL/Exact_predicates_exact_constructions_kernel.h>
#include <CGAL/Polygon_2.h>
#include <boost/utility.hpp>
#include <boost/assign/list_of.hpp>
#include <boost/iterator/transform_iterator.hpp>
#include <boost/range/algorithm_ext.hpp>

using namespace std;
using namespace geofis;
using namespace CGAL;
using namespace boost;
using namespace boost::assign;

typedef Exact_predicates_exact_constructions_kernel kernel_type;
typedef Point_2<kernel_type> point_type;
typedef Polygon_2<kernel_type> polygon_type;

typedef feature<size_t, point_type, vector<double> > feature_type;
typedef vector<feature_type> vector_feature_type;

typedef zone<polygon_type, feature_type> zone_type;
typedef vector<zone_type> vector_zone_type;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class zone_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( zone_tester );

	CPPUNIT_TEST( test );

	CPPUNIT_TEST_SUITE_END();

public:

	struct test_zone_feature {

		template <class Zone, class Feature> void operator() (const Zone &zone, const Feature &feature) const {
			CPPUNIT_ASSERT_EQUAL( (size_t)1, zone.size() );
			CPPUNIT_ASSERT_EQUAL( addressof(feature), addressof(*zone.feature_begin()) );
		}
	};

	void test() {

		try {

			vector_feature_type features = list_of(feature_type(0, point_type(), list_of(0.0)(0.1)))(feature_type(1, point_type(), list_of(0.0)(0.1)))(feature_type(2, point_type(), list_of(0.0)(0.1)));

			zone_type zone(features);
			CPPUNIT_ASSERT_EQUAL( addressof<const feature_type>(features[0]), addressof(*zone.feature_begin()) );
			CPPUNIT_ASSERT_EQUAL( addressof<const feature_type>(features[1]), addressof(*next(zone.feature_begin(), 1)) );
			CPPUNIT_ASSERT_EQUAL( addressof<const feature_type>(features[2]), addressof(*next(zone.feature_begin(), 2)) );

			vector_zone_type zones(make_transform_iterator(features.begin(), make_zone<polygon_type, feature_type>()), make_transform_iterator(features.end(), make_zone<polygon_type, feature_type>()));

			CPPUNIT_ASSERT_EQUAL( (size_t)3, zones.size() );
			for_each(zones, features, test_zone_feature());

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( zone_tester );

