/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/algorithm/zoning/triangulation/voronoi/voronoi_map.hpp>
#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/specializations.hpp>
#include <CGAL/Exact_predicates_exact_constructions_kernel.h>
#include <CGAL/Polygon_with_holes_2.h>
#include <boost/ref.hpp>
#include <boost/assign/list_of.hpp>
#include <boost/range/adaptor/transformed.hpp>
#include <geofis/geometry/polygon.hpp>
#include <geofis/algorithm/zoning/triangulation/edge_to_info_adaptor.hpp>
#include <geofis/data/feature.hpp>
#include <geofis/algorithm/zoning/fusion/zone.hpp>
#include <geofis/algorithm/zoning/fusion/voronoi/zone_info.hpp>

using namespace std;
using namespace geofis;
using namespace CGAL;
using namespace boost;
using namespace boost::assign;
using namespace boost::adaptors;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

typedef Exact_predicates_exact_constructions_kernel kernel_type;
typedef Point_2<kernel_type> point_type;
typedef Polygon_2<kernel_type> polygon_type;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

template <class Feature> struct edge_type {

	edge_type(const Feature &feature1, const Feature &feature2) : feature1(feature1), feature2(feature2) {}

	const Feature &get_feature1() const { return feature1; }
	const Feature &get_feature2() const { return feature2; }

	reference_wrapper<const Feature> feature1;
	reference_wrapper<const Feature> feature2;
};

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

namespace test {

struct feature_type {

	typedef point_type geometry_type;

	feature_type(const point_type &point) : point(point) {}

	const point_type &get_geometry() const { return point; }

	point_type point;
};

typedef voronoi_map<kernel_type, feature_type> voronoi_map_type;

typedef typename voronoi_zone_traits<kernel_type, feature_type>::voronoi_zone_type voronoi_zone_type;

struct zone_info_type {

	zone_info_type() : voronoi_zone(NULL) {}
	zone_info_type(voronoi_zone_type &voronoi_zone) : voronoi_zone(addressof(voronoi_zone)) {}

	void set_geometry(const polygon_type &geometry) {
		UTIL_REQUIRE(voronoi_zone);
		voronoi_zone->set_geometry(geometry);
	}

	const voronoi_zone_type &get_voronoi_zone() const {
		UTIL_REQUIRE(voronoi_zone);
		return *voronoi_zone;
	}

	voronoi_zone_type *voronoi_zone;
};

struct zone_info_builder_type {

	typedef zone_info_type result_type;

	result_type operator()(voronoi_zone_type &voronoi_zone) const {
		return result_type(voronoi_zone);
	}
};

template <class VoronoiZoneRange> struct zone_info_range_traits {

	typedef transform_range<zone_info_builder_type, VoronoiZoneRange> zone_info_range_type;
};

struct zone_info_policy_type {

	typedef zone_info_type info_type;

	template <class VoronoiZoneRange> typename zone_info_range_traits<VoronoiZoneRange>::zone_info_range_type make_info_range(VoronoiZoneRange &voronoi_zones) const {
		return transform(voronoi_zones, zone_info_builder_type());
	}
};

typedef voronoi_map<kernel_type, feature_type, const zone_info_policy_type> voronoi_map_zone_info_type;

} // namespace test

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

namespace geofis {

typedef feature<int, point_type, vector<double> > feature_type;
typedef voronoi_map<kernel_type, feature_type> voronoi_map_type;
typedef typename voronoi_zone_traits<kernel_type, feature_type>::voronoi_zone_type voronoi_zone_type;
typedef Polygon_with_holes_2<kernel_type> polygon_with_holes_type;
typedef zone<polygon_with_holes_type, voronoi_zone_type> zone_type;
typedef zone_info_policy<zone_type, voronoi_zone_type> zone_info_policy_type;
typedef voronoi_map<kernel_type, feature_type, zone_info_policy_type> voronoi_map_zone_info_type;

} // geofis

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class voronoi_map_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( voronoi_map_tester );

	CPPUNIT_TEST( test_unit );
	CPPUNIT_TEST( test_geofis );

	CPPUNIT_TEST_SUITE_END();

public:

	template <class Feature> inline static bool feature_equals(const Feature &feature1, const Feature &feature2) {
		return addressof(feature1) == addressof(feature2);
	}

	struct test_feature_address {

		template <class Feature, class Zone> bool operator()(const Feature &feature, const Zone &zone) {
			return feature_equals(feature, zone.get_feature());
		}
	};

	template <class FeatureRange, class ZoneRange> void test_features(const FeatureRange &features, const ZoneRange &zones) {
		CPPUNIT_ASSERT_EQUAL( 5, distance(zones) );
		CPPUNIT_ASSERT_RANGES_EQUAL_PREDICATE( features, zones, test_feature_address() );
	}

	struct test_geometry {

		template <class Geometry, class Zone> bool operator()(const Geometry &geometry, const Zone &zone) {
			return geometry == zone.get_geometry();
		}
	};

	template <class GeometryRange, class ZoneRange> void test_geometries(const GeometryRange &geometries, const ZoneRange &zones) {
		CPPUNIT_ASSERT_EQUAL( 5, distance(zones) );
		CPPUNIT_ASSERT_RANGES_EQUAL_PREDICATE( geometries, zones, test_geometry() );
	}

	struct test_edge {

		template <class EdgeTester, class Edge> bool operator()(const EdgeTester &edge_tester, const Edge &edge) {
			return edge_tester(edge);
		}
	};

	template <class ExpectedEdge> struct edge_tester {

		typedef bool result_type;

		edge_tester(const ExpectedEdge &expected_edge) : expected_edge(expected_edge) {}

		template <class Info> result_type operator()(const Info &info1, const Info &info2) const {
			return feature_equals(expected_edge.get_feature1(), info1.get_voronoi_zone().get_feature()) && feature_equals(expected_edge.get_feature2(), info2.get_voronoi_zone().get_feature());
		}

		const ExpectedEdge &expected_edge;
	};

	template <class ExpectedEdge> struct edge_tester_builder {

		typedef edge_tester<ExpectedEdge> edge_tester_type;
		typedef edge_to_info_adaptor<edge_tester_type> result_type;

		result_type operator()(const ExpectedEdge &expected_edge) const {
			return make_edge_to_info_adaptor(edge_tester_type(expected_edge));
		}
	};

	template <class ExpectedEdgeRange, class EdgeRange> void test_finite_edges(const ExpectedEdgeRange &expected_edges, const EdgeRange &edges) {

		typedef typename range_value<ExpectedEdgeRange>::type expected_edge_type;

		CPPUNIT_ASSERT_EQUAL( 8, distance(edges) );
		CPPUNIT_ASSERT_RANGES_EQUAL_PREDICATE( transform(expected_edges, edge_tester_builder<expected_edge_type>()), edges, test_edge() );
	}

	polygon_type get_boundary_polygon() {
		return make_polygon<kernel_type>(list_of(point_type(0, 0))(point_type(6, 0))(point_type(6, 6))(point_type(0, 6)));
	}

	vector<polygon_type> get_expected_geometries() {
		polygon_type polygon1 = make_polygon<kernel_type>(list_of(point_type(0, 0))(point_type(3, 0))(point_type(3, 1))(point_type(1, 3))(point_type(0, 3)));
		polygon_type polygon2 = make_polygon<kernel_type>(list_of(point_type(3, 0))(point_type(6, 0))(point_type(6, 3))(point_type(5, 3))(point_type(3, 1)));
		polygon_type polygon3 = make_polygon<kernel_type>(list_of(point_type(6, 3))(point_type(6, 6))(point_type(3, 6))(point_type(3, 5))(point_type(5, 3)));
		polygon_type polygon4 = make_polygon<kernel_type>(list_of(point_type(3, 6))(point_type(0, 6))(point_type(0, 3))(point_type(1, 3))(point_type(3, 5)));
		polygon_type polygon5 = make_polygon<kernel_type>(list_of(point_type(3, 1))(point_type(5, 3))(point_type(3, 5))(point_type(1, 3)));
		return list_of(polygon1)(polygon2)(polygon3)(polygon4)(polygon5);
	}

	template <class Feature> vector<edge_type<Feature> > get_expected_edges(const vector<Feature> &features) {
		edge_type<Feature> edge1(features[3], features[2]);
		edge_type<Feature> edge2(features[1], features[0]);
		edge_type<Feature> edge3(features[0], features[4]);
		edge_type<Feature> edge4(features[4], features[3]);
		edge_type<Feature> edge5(features[3], features[0]);
		edge_type<Feature> edge6(features[1], features[2]);
		edge_type<Feature> edge7(features[2], features[4]);
		edge_type<Feature> edge8(features[4], features[1]);
		return list_of(edge1)(edge2)(edge3)(edge4)(edge5)(edge6)(edge7)(edge8);
	}

	void test_unit() {

		try {

			vector<test::feature_type> features = list_of<test::feature_type>(point_type(1, 1))(point_type(5, 1))(point_type(5, 5))(point_type(1, 5))(point_type(3, 3));

			{
				voronoi_map.initialize(features, get_boundary_polygon());
				voronoi_map.initialize(features, get_boundary_polygon());
				test_features(features, voronoi_map.get_zones());
				test_geometries(get_expected_geometries(), voronoi_map.get_zones());
				test_finite_edges(get_expected_edges(features), voronoi_map.get_finite_edges());
			}

			{
				voronoi_map_zone_info.initialize(features, get_boundary_polygon(), test::zone_info_policy_type());
				voronoi_map_zone_info.initialize(features, get_boundary_polygon(), test::zone_info_policy_type());
				test_features(features, voronoi_map_zone_info.get_zones());
				test_geometries(get_expected_geometries(), voronoi_map_zone_info.get_zones());
				test_finite_edges(get_expected_edges(features), voronoi_map_zone_info.get_finite_edges());
			}

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}

	struct test_zone {

		template <class VoronoiZone> bool test_voronoi_zones(const VoronoiZone &voronoi_zone1, const VoronoiZone &voronoi_zone2) {
			return addressof(voronoi_zone1) == addressof(voronoi_zone2);
		}

		template <class Zone, class VoronoiZone> bool operator()(const Zone &zone, const VoronoiZone &voronoi_zone) {
			CPPUNIT_ASSERT_EQUAL( 1, distance(zone.get_voronoi_zones()) );
			return test_voronoi_zones(*begin(zone.get_voronoi_zones()), voronoi_zone);
		}
	};

	template <class ZoneRange, class VoronoiZoneRange> void test_zones(const ZoneRange &zones, const VoronoiZoneRange &voronoi_zones) {
		CPPUNIT_ASSERT_RANGES_EQUAL_PREDICATE( zones, voronoi_zones, test_zone() );
	}

	void test_geofis() {

		vector<feature_type> features = list_of(feature_type(0, point_type(1, 1), list_of(0)))(feature_type(1, point_type(5, 1), list_of(1)))(feature_type(2, point_type(5, 5), list_of(2)))(feature_type(3, point_type(1, 5), list_of(3)))(feature_type(4, point_type(3, 3), list_of(4)));

		{
			geofis_voronoi_map.initialize(features, get_boundary_polygon());
			geofis_voronoi_map.initialize(features, get_boundary_polygon());
			test_features(features, geofis_voronoi_map.get_zones());
			test_geometries(get_expected_geometries(), geofis_voronoi_map.get_zones());
			test_finite_edges(get_expected_edges(features), geofis_voronoi_map.get_finite_edges());
		}

		{
			zone_info_policy_type zone_info_policy;
			geofis_voronoi_map_zone_info.initialize(features, get_boundary_polygon(), zone_info_policy);
			geofis_voronoi_map_zone_info.initialize(features, get_boundary_polygon(), zone_info_policy);
			test_features(features, geofis_voronoi_map_zone_info.get_zones());
			test_geometries(get_expected_geometries(), geofis_voronoi_map_zone_info.get_zones());
			test_finite_edges(get_expected_edges(features), geofis_voronoi_map_zone_info.get_finite_edges());
			test_geometries(get_expected_geometries(), zone_info_policy);
			test_zones(zone_info_policy, geofis_voronoi_map_zone_info.get_zones());
		}
	}

	test::voronoi_map_type voronoi_map;
	test::voronoi_map_zone_info_type voronoi_map_zone_info;
	voronoi_map_type geofis_voronoi_map;
	voronoi_map_zone_info_type geofis_voronoi_map_zone_info;
};

CPPUNIT_TEST_SUITE_REGISTRATION( voronoi_map_tester );

