/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/data/attribute_range.hpp>
#include <geofis/data/feature.hpp>
#include <boost/assign/list_of.hpp>
#include <boost/range/adaptor/indexed.hpp>
#include <pstade/oven/counting.hpp>
#include <vector>
#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/specializations.hpp>

using namespace std;
using namespace geofis;
using namespace boost;
using namespace boost::assign;
using namespace boost::adaptors;
using namespace pstade::oven;

struct geometry_type {};

typedef feature<char, geometry_type, int32_t> feature_mono_attribute_type;
typedef feature<char, geometry_type, vector<int32_t> > feature_multi_attribute_type;

#define EPSILON 1e-6

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class attribute_range_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( attribute_range_tester );

	CPPUNIT_TEST( test_attribute_range_mono_attribute );
	CPPUNIT_TEST( test_attribute_range_multi_attribute );

	CPPUNIT_TEST_SUITE_END();

public:

	template <class Range> void test_attribute_range_mono_attribute(const Range &range) {
		test_attribute_range_mono_attribute(begin(range), end(range));
	}

	template <class Iterator> void test_attribute_range_mono_attribute(Iterator it, Iterator end) {
	    for(; it != end; ++it)
			CPPUNIT_ASSERT_EQUAL( it.index(), *it );
	}

	void test_attribute_range_mono_attribute() {

		try {

			feature_mono_attribute_type feature1('a', geometry_type(), 1);
			feature_mono_attribute_type feature2('b', geometry_type(), 2);
			feature_mono_attribute_type feature3('c', geometry_type(), 3);


		} catch(exception &e) { CPPUNIT_FAIL( e.what() ); }
	}

	template <class Range> void test_attribute_range_multi_attribute(const Range &range) {
		test_attribute_range_multi_attribute(begin(range), end(range));
	}

	template <class Iterator> void test_attribute_range_multi_attribute(Iterator it, Iterator end) {
	    for(; it != end; ++it)
	    	CPPUNIT_ASSERT_RANGES_EQUAL( counting(it.index(), it.index() + 3), *it );
	}

	void test_attribute_range_multi_attribute() {

		try {

			feature_multi_attribute_type feature1('a', geometry_type(), list_of(1)(2)(3));
			feature_multi_attribute_type feature2('b', geometry_type(), list_of(2)(3)(4));
			feature_multi_attribute_type feature3('c', geometry_type(), list_of(3)(4)(5));

			test_attribute_range_multi_attribute(index(make_attribute_range(make_iterator_range(list_of(feature1)(feature2)(feature3))), 1));

		} catch(exception &e) { CPPUNIT_FAIL( e.what() ); }
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( attribute_range_tester );
