/**
 * Util Native Library
 *
 * Copyright (C) 2014 IRSTEA
 *
 * Auteur/Author:
 *     Jean-luc Lablée - http://itap.irstea.fr/?page_id=2277
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL-C soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL-C telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL-C, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL-C license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL-C
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C license and that you accept its terms.
 */
#include <util/data/any_loader.hpp>
#include <util/data/data_loader.hpp>
#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/specializations.hpp>
#include <cppunit/specializations/data/data.hpp>
#include <boost/serialization/vector.hpp>
#include <boost/serialization/auto_ptr.hpp>
#include <boost/assign/list_of.hpp>
#include <boost/archive/xml_iarchive.hpp>
#include <boost/archive/xml_oarchive.hpp>
#include <boost/range/counting_range.hpp>
#include <vector>

using namespace util;
using namespace boost;

class any_loader_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( any_loader_tester );

	CPPUNIT_TEST( test );
	CPPUNIT_TEST( test_serialization );

	CPPUNIT_TEST_SUITE_END();

public:

	void test() {

		try {

			data<int>::auto_ptr d(new_data(make_any_loader(counting_range(0, 5))));
			CPPUNIT_ASSERT_EQUAL( (size_t)5, d->size() );
			CPPUNIT_ASSERT_RANGES_EQUAL( counting_range(0, 5), *d );

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}

	void test_serialization() {

		try {

			std::vector<int> v = boost::assign::list_of<int>(0)(1)(2)(3)(4);
			data<int>::auto_ptr data_out(new_data(make_any_loader(v)));
			std::ofstream ofs("../util_files/data/data_any_loader.xml");
			assert(ofs.good());
			boost::archive::xml_oarchive oa(ofs);
			oa.register_type<data_loader<any_loader<int> > >();
			oa.register_type<util::detail::concrete_loader<std::vector<int> > >();
			oa << BOOST_SERIALIZATION_NVP(data_out);
			ofs.close();

			std::ifstream ifs("../util_files/data/data_any_loader.xml");
			assert(ifs.good());
			boost::archive::xml_iarchive ia(ifs);
			ia.register_type<data_loader<any_loader<int> > >();
			ia.register_type<util::detail::concrete_loader<std::vector<int> > >();
			data<int>::auto_ptr data_in;
			ia >> BOOST_SERIALIZATION_NVP(data_in);
			ifs.close();

			CPPUNIT_ASSERT_EQUAL( *data_out, *data_in );

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( any_loader_tester );

